@@ -11,13 +11,13 @@ use std::time::Duration;
 use async_channel::bounded;
 use async_channel::Receiver;
 use async_channel::Sender;
-use async_mutex::Mutex;
+use async_lock::Mutex;
 use bytes::BytesMut;
 use event_listener::Event;
 use futures_util::stream::{Stream, StreamExt};
 use pin_project::{pin_project, pinned_drop};
 use tokio::select;
-use tracing::{debug, error, instrument, trace};
+use tracing::{debug, error, trace, instrument};
 
 use fluvio_future::timer::sleep;
 use fluvio_protocol::api::Request;
@@ -25,7 +25,7 @@ use fluvio_protocol::api::RequestHeader;
 use fluvio_protocol::api::RequestMessage;
 use fluvio_protocol::Decoder;
 
-use crate::FlvSocketError;
+use crate::SocketError;
 use crate::ExclusiveFlvSink;
 use crate::FluvioSocket;
 use crate::FluvioStream;
@@ -100,10 +100,11 @@ impl MultiplexerSocket {
     }
 
     /// create socket to perform request and response
+    #[instrument(skip(self, req_msg))]
     pub async fn send_and_receive<R>(
         &self,
         mut req_msg: RequestMessage<R>,
-    ) -> Result<R::Response, FlvSocketError>
+    ) -> Result<R::Response, SocketError>
     where
         R: Request,
     {
@@ -185,11 +186,12 @@ impl MultiplexerSocket {
     }
 
     /// create stream response
+    #[instrument(skip(self, req_msg, queue_len))]
     pub async fn create_stream<R>(
         &self,
         mut req_msg: RequestMessage<R>,
         queue_len: usize,
-    ) -> Result<AsyncResponse<R>, FlvSocketError>
+    ) -> Result<AsyncResponse<R>, SocketError>
     where
         R: Request,
     {
@@ -245,7 +247,7 @@ impl<R> PinnedDrop for AsyncResponse<R> {
 }
 
 impl<R: Request> Stream for AsyncResponse<R> {
-    type Item = Result<R::Response, FlvSocketError>;
+    type Item = Result<R::Response, SocketError>;
 
     #[instrument(
         skip(self, cx),
@@ -273,7 +275,7 @@ impl<R: Request> Stream for AsyncResponse<R> {
         let bytes = if let Some(bytes) = bytes {
             bytes
         } else {
-            return Poll::Ready(Some(Err(FlvSocketError::SocketClosed)));
+            return Poll::Ready(Some(Err(SocketError::SocketClosed)));
         };
 
         let mut cursor = Cursor::new(&bytes);
@@ -369,7 +371,8 @@ impl MultiPlexingResponseDispatcher {
     }
 
     /// send message to correct receiver
-    pub async fn send(&mut self, correlation_id: i32, msg: BytesMut) -> Result<(), FlvSocketError> {
+    #[instrument(skip(self, msg))]
+    pub async fn send(&mut self, correlation_id: i32, msg: BytesMut) -> Result<(), SocketError> {
         let mut senders = self.senders.lock().await;
         if let Some(sender) = senders.get_mut(&correlation_id) {
             match sender {
@@ -433,13 +436,11 @@ mod tests {
     use fluvio_future::net::TcpListener;
     use fluvio_future::net::TcpStream;
     use fluvio_future::task::spawn;
-    use fluvio_future::test_async;
     use fluvio_future::timer::sleep;
     use fluvio_protocol::api::RequestMessage;
 
     use super::MultiplexerSocket;
     use crate::test_request::*;
-    use crate::FlvSocketError;
     use crate::ExclusiveFlvSink;
     use crate::FluvioSocket;
 
@@ -637,8 +638,8 @@ mod tests {
         assert!(slow > fast);
     }
 
-    #[test_async]
-    async fn test_multiplexing() -> Result<(), FlvSocketError> {
+    #[fluvio_future::test(ignore)]
+    async fn test_multiplexing() {
         debug!("start testing");
         let addr = "127.0.0.1:6000";
 
@@ -647,7 +648,6 @@ mod tests {
             test_server(addr, TcpStreamHandler {}),
         )
         .await;
-        Ok(())
     }
 
     #[cfg(unix)]
@@ -732,8 +732,8 @@ mod tests {
             }
         }
 
-        #[test_async]
-        async fn test_multiplexing_native_tls() -> Result<(), FlvSocketError> {
+        #[fluvio_future::test(ignore)]
+        async fn test_multiplexing_native_tls() {
             debug!("start testing");
             let addr = "127.0.0.1:6001";
 
@@ -742,7 +742,6 @@ mod tests {
                 test_server(addr, TlsAcceptorHandler::new()),
             )
             .await;
-            Ok(())
         }
     }
 }
