@@ -2,37 +2,26 @@ use std::fmt;
 use std::fmt::Debug;
 use std::sync::Arc;
 
-use std::os::unix::io::AsRawFd;
-use std::os::unix::io::RawFd;
-
-use async_mutex::Mutex;
-use async_mutex::MutexGuard;
 use tracing::trace;
-use tokio_util::compat::FuturesAsyncWriteCompatExt;
-use futures_util::SinkExt;
-
-use tokio_util::compat::Compat;
-use bytes::BytesMut;
-
-use fluvio_future::zero_copy::ZeroCopy;
-use fluvio_protocol::api::RequestMessage;
-use fluvio_protocol::api::ResponseMessage;
-use fluvio_protocol::codec::FluvioCodec;
-use fluvio_protocol::store::FileWrite;
-use fluvio_protocol::store::StoreValue;
-use fluvio_protocol::Encoder as FlvEncoder;
-use fluvio_protocol::Version;
-use fluvio_future::net::BoxWriteConnection;
-
+use futures_util::{SinkExt};
+use async_lock::Mutex;
+use async_lock::MutexGuard;
+use tokio_util::compat::{Compat, FuturesAsyncWriteCompatExt};
 use tokio_util::codec::{FramedWrite};
 
-use crate::FlvSocketError;
+use fluvio_protocol::api::{RequestMessage, ResponseMessage};
+use fluvio_protocol::codec::FluvioCodec;
+use fluvio_protocol::Encoder as FlvEncoder;
+use fluvio_protocol::Version;
+use fluvio_future::net::{BoxWriteConnection, ConnectionFd};
+
+use crate::SocketError;
 
 type SinkFrame = FramedWrite<Compat<BoxWriteConnection>, FluvioCodec>;
 
 pub struct FluvioSink {
     inner: SinkFrame,
-    fd: RawFd,
+    fd: ConnectionFd,
 }
 
 impl fmt::Debug for FluvioSink {
@@ -46,8 +35,9 @@ impl FluvioSink {
         &mut self.inner
     }
 
-    pub fn id(&self) -> RawFd {
-        self.fd
+    pub fn id(&self) -> ConnectionFd {
+        #[allow(clippy::clone_on_copy)]
+        self.fd.clone()
     }
 
     /// convert to shared sink
@@ -56,7 +46,7 @@ impl FluvioSink {
         ExclusiveFlvSink::new(self)
     }
 
-    pub fn new(sink: BoxWriteConnection, fd: RawFd) -> Self {
+    pub fn new(sink: BoxWriteConnection, fd: ConnectionFd) -> Self {
         Self {
             fd,
             inner: SinkFrame::new(sink.compat_write(), FluvioCodec::new()),
@@ -64,20 +54,12 @@ impl FluvioSink {
     }
 
     /// as client, send request to server
-    pub async fn send_request<R>(
-        &mut self,
-        req_msg: &RequestMessage<R>,
-    ) -> Result<(), FlvSocketError>
+    pub async fn send_request<R>(&mut self, req_msg: &RequestMessage<R>) -> Result<(), SocketError>
     where
         RequestMessage<R>: FlvEncoder + Default + Debug,
     {
-        let bytes = req_msg.as_bytes(0)?;
-        trace!(
-            "sending one way request: {:#?}, bytes: {}",
-            &req_msg,
-            bytes.len()
-        );
-        (&mut self.inner).send(bytes).await?;
+        trace!("sending one way request: {:#?}", &req_msg,);
+        (&mut self.inner).send((req_msg, 0)).await?;
         Ok(())
     }
 
@@ -86,78 +68,104 @@ impl FluvioSink {
         &mut self,
         resp_msg: &ResponseMessage<P>,
         version: Version,
-    ) -> Result<(), FlvSocketError>
+    ) -> Result<(), SocketError>
     where
         ResponseMessage<P>: FlvEncoder + Default + Debug,
     {
-        let bytes = resp_msg.as_bytes(version)?;
-        trace!("sending response {:#?}, bytes: {}", &resp_msg, bytes.len());
-        (&mut self.inner).send(bytes).await?;
+        trace!("sending response {:#?}", &resp_msg);
+        (&mut self.inner).send((resp_msg, version)).await?;
         Ok(())
     }
 }
 
-impl FluvioSink {
-    /// write
-    pub async fn encode_file_slices<T>(
-        &mut self,
-        msg: &T,
-        version: Version,
-    ) -> Result<(), FlvSocketError>
-    where
-        T: FileWrite,
-    {
-        trace!("encoding file slices version: {}", version);
-        let mut buf = BytesMut::with_capacity(1000);
-        let mut data: Vec<StoreValue> = vec![];
-        msg.file_encode(&mut buf, &mut data, version)?;
-        trace!("encoded buffer len: {}", buf.len());
-        // add remainder
-        data.push(StoreValue::Bytes(buf.freeze()));
-        self.write_store_values(data).await
+#[cfg(unix)]
+mod fd {
+
+    use std::os::unix::io::AsRawFd;
+    use std::os::unix::io::RawFd;
+
+    use super::FluvioSink;
+
+    impl AsRawFd for FluvioSink {
+        fn as_raw_fd(&self) -> RawFd {
+            self.fd
+        }
     }
+}
 
-    /// write store values to socket
-    async fn write_store_values(&mut self, values: Vec<StoreValue>) -> Result<(), FlvSocketError> {
-        trace!("writing store values to socket values: {}", values.len());
+#[cfg(feature = "file")]
+mod file {
 
-        for value in values {
-            match value {
-                StoreValue::Bytes(bytes) => {
-                    trace!("writing store bytes to socket len: {}", bytes.len());
-                    self.get_mut_tcp_sink().send(bytes).await?;
-                }
-                StoreValue::FileSlice(f_slice) => {
-                    if f_slice.is_empty() {
-                        trace!("empty slice, skipping");
-                    } else {
-                        trace!(
-                            "writing file slice pos: {} len: {} to socket",
-                            f_slice.position(),
-                            f_slice.len()
-                        );
-                        let writer = ZeroCopy::raw(self.fd);
-                        writer.copy_slice(&f_slice).await?;
-                        trace!("finish writing file slice");
+    use bytes::BytesMut;
+    use futures_util::AsyncWriteExt;
+
+    use fluvio_protocol::store::{FileWrite, StoreValue};
+    use fluvio_future::zero_copy::ZeroCopy;
+
+    use super::*;
+
+    impl FluvioSink {
+        /// write
+        pub async fn encode_file_slices<T>(
+            &mut self,
+            msg: &T,
+            version: Version,
+        ) -> Result<(), SocketError>
+        where
+            T: FileWrite,
+        {
+            trace!("encoding file slices version: {}", version);
+            let mut buf = BytesMut::with_capacity(1000);
+            let mut data: Vec<StoreValue> = vec![];
+            msg.file_encode(&mut buf, &mut data, version)?;
+            trace!("encoded buffer len: {}", buf.len());
+            // add remainder
+            data.push(StoreValue::Bytes(buf.freeze()));
+            self.write_store_values(data).await
+        }
+
+        /// write store values to socket
+        async fn write_store_values(&mut self, values: Vec<StoreValue>) -> Result<(), SocketError> {
+            trace!("writing store values to socket values: {}", values.len());
+
+            for value in values {
+                match value {
+                    StoreValue::Bytes(bytes) => {
+                        trace!("writing store bytes to socket len: {}", bytes.len());
+                        // These bytes should be already encoded so don't need to pass
+                        // through the FluvioCodec
+                        self.get_mut_tcp_sink()
+                            .get_mut()
+                            .get_mut()
+                            .write(&bytes)
+                            .await?;
+                    }
+                    StoreValue::FileSlice(f_slice) => {
+                        if f_slice.is_empty() {
+                            trace!("empty slice, skipping");
+                        } else {
+                            trace!(
+                                "writing file slice pos: {} len: {} to socket",
+                                f_slice.position(),
+                                f_slice.len()
+                            );
+                            let writer = ZeroCopy::raw(self.fd);
+                            writer.copy_slice(&f_slice).await?;
+                            trace!("finish writing file slice");
+                        }
                     }
                 }
             }
+
+            Ok(())
         }
-
-        Ok(())
-    }
-}
-
-impl AsRawFd for FluvioSink {
-    fn as_raw_fd(&self) -> RawFd {
-        self.fd
     }
 }
 
 /// Multi-thread aware Sink.  Only allow sending request one a time.
 pub struct ExclusiveFlvSink {
     inner: Arc<Mutex<FluvioSink>>,
-    fd: RawFd,
+    fd: ConnectionFd,
 }
 
 impl ExclusiveFlvSink {
@@ -175,7 +183,7 @@ impl ExclusiveFlvSink {
         self.inner.lock().await
     }
 
-    pub async fn send_request<R>(&self, req_msg: &RequestMessage<R>) -> Result<(), FlvSocketError>
+    pub async fn send_request<R>(&self, req_msg: &RequestMessage<R>) -> Result<(), SocketError>
     where
         RequestMessage<R>: FlvEncoder + Default + Debug,
     {
@@ -188,7 +196,7 @@ impl ExclusiveFlvSink {
         &mut self,
         resp_msg: &ResponseMessage<P>,
         version: Version,
-    ) -> Result<(), FlvSocketError>
+    ) -> Result<(), SocketError>
     where
         ResponseMessage<P>: FlvEncoder + Default + Debug,
     {
@@ -196,16 +204,18 @@ impl ExclusiveFlvSink {
         inner_sink.send_response(resp_msg, version).await
     }
 
-    pub fn id(&self) -> RawFd {
-        self.fd
+    pub fn id(&self) -> ConnectionFd {
+        #[allow(clippy::clone_on_copy)]
+        self.fd.clone()
     }
 }
 
 impl Clone for ExclusiveFlvSink {
     fn clone(&self) -> Self {
+        #[allow(clippy::clone_on_copy)]
         Self {
             inner: self.inner.clone(),
-            fd: self.fd,
+            fd: self.fd.clone(),
         }
     }
 }
@@ -218,14 +228,14 @@ mod tests {
 
     use async_net::TcpListener;
     use bytes::BufMut;
-    use bytes::Bytes;
     use futures_util::future::join;
-    use futures_util::{SinkExt, StreamExt};
+    use futures_util::StreamExt;
+    use futures_util::io::AsyncWriteExt;
     use tracing::debug;
     use tracing::info;
 
     use crate::FluvioSocket;
-    use crate::FlvSocketError;
+    use crate::SocketError;
     use fluvio_future::fs::util;
     use fluvio_future::fs::AsyncFileExtension;
     use fluvio_future::test_async;
@@ -233,7 +243,7 @@ mod tests {
     use fluvio_future::zero_copy::ZeroCopy;
     use fluvio_protocol::{Decoder, Encoder};
 
-    async fn test_server(addr: &str) -> Result<(), FlvSocketError> {
+    async fn test_server(addr: &str) -> Result<(), SocketError> {
         let listener = TcpListener::bind(&addr).await.expect("bind");
         debug!("server is running");
         let mut incoming = listener.incoming();
@@ -251,7 +261,7 @@ mod tests {
         len.encode(&mut out, 0).expect("encode"); // codec len
         out.put_u16(TEXT_LEN as u16); // string message len
 
-        raw_tcp_sink.send(Bytes::from(out)).await.expect("send");
+        raw_tcp_sink.get_mut().get_mut().write(&out).await?;
 
         // send out file
         debug!("sending out file contents");
@@ -267,10 +277,10 @@ mod tests {
         Ok(())
     }
 
-    async fn setup_client(addr: &str) -> Result<(), FlvSocketError> {
+    async fn setup_client(addr: &str) -> Result<(), SocketError> {
         sleep(Duration::from_millis(50)).await;
         debug!("client: trying to connect");
-        let mut socket = FluvioSocket::connect(&addr).await.expect("connect");
+        let mut socket = FluvioSocket::connect(addr).await.expect("connect");
         info!("client: connect to test server and waiting...");
         let stream = socket.get_mut_stream();
         let next_value = stream.get_mut_tcp_stream().next().await;
@@ -287,7 +297,7 @@ mod tests {
     }
 
     #[test_async]
-    async fn test_sink_copy() -> Result<(), FlvSocketError> {
+    async fn test_sink_copy() -> Result<(), SocketError> {
         let addr = "127.0.0.1:9999";
 
         let _r = join(setup_client(addr), test_server(addr)).await;
